@@ -1,7 +1,6 @@
-/* $Id: recvfrom.h,v 1.3 2001/11/14 02:54:25 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
- *   Copyright 2001 H. Peter Anvin - All Rights Reserved
+ *   Copyright 2001-2006 H. Peter Anvin - All Rights Reserved
  *
  *   This program is free software available under the same license
  *   as the "OpenBSD" operating system, distributed at
@@ -20,5 +19,5 @@
 
 int
 myrecvfrom(int s, void *buf, int len, unsigned int flags,
-	   struct sockaddr *from, int *fromlen,
+	   struct sockaddr *from, socklen_t *fromlen,
 	   struct sockaddr_in *myaddr);
